from .video import h264_frame_to_cuda, h264_frame_to_numpy_array, decoded_frame_to_cuda, decoded_frame_to_numpy_array, NoFrameData, DecodedFrame, H264DecoderAsync
from .coco import get_coco_class, get_coco_class_by_id, get_coco_class_by_name
from .app import run_jetson_tello_app



from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(name='jetson_tello',
      version='1.1.2',
      description='Tello drone integration with Jetson',
      long_description=long_description,
      long_description_content_type="text/markdown",
      url='https://github.com/robagar/jetson-tello',
      project_urls={
        'Documentation': 'https://jetson-tello.readthedocs.io/en/latest/'
      },
      author='Rob Agar',
      author_email='tello_asyncio@fastmail.net',
      license='LGPL',
      packages=['jetson_tello'],
      zip_safe=False,
      python_requires=">=3.6",
      install_requires=[
        'tello-asyncio >= 1.6.0'
      ])